`xotl.tools.future.codecs`:mod: - Codec registry, base classes and tools
========================================================================

.. module:: xotl.tools.future.codecs

This module complements the standard library's `codecs`:mod:.

.. autofunction:: force_encoding

.. autofunction:: safe_decode

.. autofunction:: safe_encode
